package org.eco.common.core.exception;

import cn.hutool.core.util.StrUtil;
import lombok.Getter;

import java.io.Serial;
import java.text.MessageFormat;

/**
 * 业务异常
 *
 * @author wgk
 */
public final class ServiceException extends RuntimeException {
    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 错误码
     */
    @Getter
    private Integer code;

    /**
     * 错误参数
     */
    private Object[] msgParams;

    /**
     * 错误明细，内部调试错误
     */
    private String message;

    /**
     * 空构造方法，避免反序列化问题
     */
    public ServiceException() {
    }

    public ServiceException(String message) {
        this.message = message;
    }
    public ServiceException(String message, Integer code) {
        this.message = message;
        this.code = code;
    }

    public ServiceException(Integer code, String msg, Object... msgParams) {
        this.message = msg;
        this.code = code;
        this.msgParams = msgParams;
    }

    public ServiceException(String msg, Object... msgParams) {
        this.message = msg;
        this.msgParams = msgParams;
    }

    @Override
    public String getMessage() {
        if(StrUtil.isNotBlank(getMessage())){
            if(msgParams!=null && msgParams.length>0){
                return MessageFormat.format(message, msgParams);
            }
        }
        return super.getMessage(); // 如果不传参数，直接调用父类方法
    }

    public ServiceException setMessage(String message) {
        this.message = message;
        return this;
    }

}
